﻿/*

	XMLConfigReader
	
	This class reads from the XML file,
	garners out the configuration information,
	makes a value object from it,
	and emits an event when it's done.
	
	Anytime you add something to the XML file,
	you'll parse it here, and typically add the
	data to the ConfigVO.
	
	by Jesse R. Warden
	jesterxl@jessewarden.com
	http://www.jessewarden.com
	
	This is release under a Creative Commons license. 
    More information can be found here:
    
    http://creativecommons.org/licenses/by/2.5/

*/
import mx.utils.Delegate;
import mx.events.EventDispatcher;

import com.jxl.ddo.model.vo.ServerConfigVO;
import com.jxl.ddo.model.vo.ConfigVO;

class com.jxl.ddo.model.XMLConfigReader
{
	public static var CONFIG_READ:String = "configRead";
	public static var CONFIG_ERROR:String = "configError";
	public static var configXMLFile:String = "ddo_server_status_config.xml";
	public static var mixit = EventDispatcher.initialize(XMLConfigReader.prototype);
	
	public var addEventListener:Function;
	public var removeEventListener:Function;
	private var dispatchEvent:Function;
	
	public var config:ConfigVO;
	
	private var config_xml:XML;
	
	public function loadConfig():Void
	{
		config_xml = new XML();
		config_xml.ignoreWhite = true;
		config_xml.onLoad = Delegate.create(this, onConfigXMLLoaded);
		config_xml.load(configXMLFile);
	}
	
	private function onConfigXMLLoaded(p_success:Boolean):Void
	{
		if(p_success)
		{
			var theProxyURL:String = config_xml.firstChild.attributes.proxy;
			var theBaseURL:String = config_xml.firstChild.firstChild.attributes.baseurl;
			var serverConfigs_array:Array = [];
			var servers_array:Array = config_xml.firstChild.firstChild.childNodes;
			var len:Number = servers_array.length;
			for(var i:Number = 0; i<len; i++)
			{
				var node:XMLNode = servers_array[i];
				var sc:ServerConfigVO = new ServerConfigVO();
				sc.name = node.attributes.name;
				sc.ip = node.attributes.ip;
				serverConfigs_array[i] = sc;
			}
			
			config = new ConfigVO();
			config.baseURL = theBaseURL;
			config.serverConfigs_array = serverConfigs_array;
			config.proxy_url = theProxyURL;
			
			dispatchEvent({type: CONFIG_READ, target: this, config: config});
		}
		else
		{
			config = null;
			dispatchEvent({type: CONFIG_ERROR, target: this});
		}
	}
}