﻿/*

	LoadServerStatusDelegate
	
	This business delegate pings the server and returns
	the status of the server.  It also handles whether
	or not we are running in a projector, and if so,
	uses a proxy to get the XML instead of just loading it.
	It uses the ServerStatusFactory to get usable 
	value objects from the XML returned.
	
	by Jesse R. Warden
	jesterxl@jessewarden.com
	http://www.jessewarden.com
	
	This is release under a Creative Commons license. 
    More information can be found here:
    
    http://creativecommons.org/licenses/by/2.5/

*/

import mx.rpc.ResultEvent;
import mx.rpc.Fault;
import mx.rpc.FaultEvent;
import mx.rpc.Responder;
import mx.utils.Delegate;

import com.jxl.ddo.model.vo.ServerStatusVO;
import com.jxl.ddo.model.factories.ServerStatusFactory;
import com.jxl.ddo.model.ModelLocator;

class com.jxl.ddo.model.business.LoadServerStatusDelegate
{
	
	private var responder:Responder;
	
	private var my_xml:XML;
	private var proxy_lv:LoadVars;
	private var onLoadDelegate:Function;
	private var onDataDelegate:Function;
	
	function LoadServerStatusDelegate(p_responder:Responder)
	{
		responder = p_responder;
		onLoadDelegate = Delegate.create(this, onXMLLoaded);
		onDataDelegate = Delegate.create(this, onDataLoaded);
	}
	
	public function getServerStatus(p_serverURL:String):Void
	{
		my_xml = new XML();
		my_xml.ignoreWhite = true;
		my_xml.onLoad = onLoadDelegate;
		
		// if we are running as a projector,
		// we don't have to worry about the security sandbox
		if(_global.mSystem != null)
		{
			my_xml.load(p_serverURL);
		}
		// ...however, if we are on the web, we have to use the proxy
		else
		{
			proxy_lv = new LoadVars();
			proxy_lv.owner = this;
			proxy_lv.onData = onDataDelegate;
			proxy_lv.filename = p_serverURL;
			proxy_lv.sendAndLoad(ModelLocator.proxy_url, proxy_lv, "POST");
		}
	}
	
	private function onDataLoaded(p_str:String):Void
	{
		if(p_str != null && p_str != "")
		{
			my_xml.parseXML(p_str);
			my_xml.loaded = true;
			my_xml.onLoad(true);
		}
		else
		{
			my_xml.onLoad(false);
		}
	}
	
	private function onXMLLoaded(p_success:Boolean):Void
	{
		if(p_success == true)
		{
			var ss:ServerStatusVO = ServerStatusFactory.getServerStatusFromXML(my_xml);
			var re:ResultEvent = new ResultEvent(ss);
			delete onLoadDelegate;
			delete my_xml;
			responder.onResult(re);
		}
		else
		{
			var fault:Fault = new Fault("failure", "xml load failure", "The XML failed to load from the server.", "XML");
			var fe:FaultEvent = new FaultEvent(fault);
			delete onLoadDelegate;
			delete my_xml;
			responder.onFault(fe);
		}
	}

}
