﻿/*

	StatusLightLabel
	
	This component creates a changeable light
	with a label to the right.  It additionally
	has a loading animation that you can show
	instead of the light.  The light was
	straight-ganked from the Macromedia Communication Components
	and is not applicable under the Creative Commons license
	here in.  All code, however, is.
	
	by Jesse R. Warden
	jesterxl@jessewarden.com
	http://www.jessewarden.com
	
	This is release under a Creative Commons license. 
    More information can be found here:
    
    http://creativecommons.org/licenses/by/2.5/

*/
import mx.core.View;
import mx.controls.Label;

class com.jxl.ddo.view.controls.StatusLightLabel extends View
{
	public static var symbolName:String = "com.jxl.ddo.view.controls.StatusLightLabel";
	public static var symbolOwner:Object = com.jxl.ddo.view.controls.StatusLightLabel;
	
	public static var STATUS_OFF:Number = 1;
	public static var STATUS_ON:Number = 2;
	public static var STATUS_WARNING:Number = 3;
	public static var STATUS_ERROR:Number = 4;
	
	public var className:String = "StatusLightLabel";
	
	private var light_mc:MovieClip;
	private var status_lbl:Label;
	private var loading_mc:MovieClip;
	
	private var __text:String = "Label";
	private var __status:Number = 0;
	private var __isLoading:Boolean = false;
	
	public function get text():String
	{
		return __text;
	}
	
	public function set text(p_str:String):Void
	{
		__text = p_str;
		status_lbl.text = __text;
	}
	
	public function get status():Number
	{
		return __status;
	}
	
	public function set status(val:Number):Void
	{
		__status = val;
		light_mc.gotoAndStop(__status);
	}
	
	public function get isLoading():Boolean
	{
		return __isLoading;
	}
	
	public function set isLoading(val:Boolean):Void
	{
		__isLoading = val;
		invalidate();
	}
	
	public function init():Void
	{
		super.init();
		
		tabEnabled = false;
		tabChildren = false;
		focusEnabled = false;
	}
	
	private function createChildren():Void
	{
		super.createChildren();
		
		if(depth == null) depth = 0;
		createObject("ConnectLight", "light_mc", depth++);
		
		createChild(Label, "status_lbl");
		status_lbl.move(18, 0);
		status_lbl.setStyle("color", 0x330000);
	}
	
	private function initLayout():Void
	{
		super.initLayout();
		
		text = text;
		status = status;
	}
	
	private function doLayout():Void
	{
		super.doLayout();
		
		light_mc._visible = !__isLoading;
		
		if(__isLoading == false)
		{
			destroyObject("loading_mc");
			light_mc._y = ( height / 2 ) - ( light_mc._height / 2);
		}
		else
		{
			createObject("LoadingAnimation", "loading_mc", depth++);
			loading_mc._x = (loading_mc._width / 2);
			var lightH2:Number = loading_mc._height / 2;
			loading_mc._y = lightH2;
			loading_mc._y += ( height / 2 ) - lightH2;
		}
		
		status_lbl.setSize(width - status_lbl.x, status_lbl.height);
	}
}