/*

Copyright 2004 iteration::two Ltd

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

@ignore
*/

import org.nevis.cairngorm.control.*;
import mx.utils.Delegate;

/**
  * If you are building a typical Cairngorm application, the <code>CairngormApplication</code> class,
  * which is a subclass of <code>mx.core.Application</code>, can be used to quickly define an application
  * with an associated controller and service locator.
  *
  * @description
  * A typical Cairngorm application main MXML file (Index.mxml) will use the tag as follows:
  *
  * <p>
  * <code>
  * <?xml version="1.0" encoding="utf-8"?>
  * <cairngorm:CairngormApplication xmlns:mx="http://www.macromedia.com/2003/mxml"
  *                 xmlns:cairngorm="org.nevis.cairngorm.application.*">
  *
  *    <cairngorm:controller>
  *        { org.nevis.cairngorm.samples.login.control.DemoControl }
  *    </cairngorm:controller>
  *
  *    <!-- Rest of application would go here -->
  *
  * </cairngorm:cairngormApplication>
  * </code>
  * </p>
  *
  * <p>
  * When creating a CairngormApplication, you are additionally asked to name the class
  * that implements your application controller; Cairngorm will then ensure that a single
  * instance of your controller is created, and will additionally warn if the controller is
  * not created successfully.
  * </p>
  *
  * <p>
  * While you are by no means obliged to use the CairngormApplication tag for your
  * applications, if you are building typical applications, the tag assumes much of
  * the heavy lifting of a framework based application, allowing you to focus on
  * the technical solution to your business problem, rather than focus on implementing
  * your own Cairngorm architecture.
  * </p>
  *
  * @see FrontController
  * @deprecated Recommendation is that users use the Application tag as the base of their application
  * due to a number of known issues with extending the Application Tag, including the inability  
  * to debug within Flex Builder.
  * 
  * <p>
  * Note that because compc, the utility used to generate the Cairngorm SWC, cannot compile components
  * that extend the Flex Application tag, the CairngormApplication class is not compiled into the
  * SWC distributed with Cairngorm. To use CairngormApplication, you must use the source distribution.
  */
  
class org.nevis.cairngorm.application.CairngormApplication extends mx.core.Application
{
   /**
     * The class defining the concrete implementation of the front controller which is
     * defined to listen for your application-specific business events, to be handled by
     * application-specific Command classes
     */
   [ClassReference]
   public var controller;

   private function init() : Void
   {
      super.init();

      addEventListener( "initialize",  Delegate.create( this, cairngormInit ) );
      addEventListener( "creationComplete",  Delegate.create( this, checkCairngormApplicationIntegrity ) );
   }

//-------------------------------------------------------------------------

   private function cairngormInit() : Void
   {
      if ( controller == undefined )
         throw new Error( "No controller was provided to CairngormApplication" );

      new controller();
   }

//-------------------------------------------------------------------------

   private function checkCairngormApplicationIntegrity()
   {
      var controllerExists:Boolean = ( this.controller != null );

      if ( !controllerExists )
         throw new Error( "No controller has been created" );
   }

}

