/*

Copyright 2004 iteration::two Ltd

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

@ignore
*/

/**
 * The Responder interface is implemented by classes that wish to handle
 * data returned as the result of a service-call to the server.
 *
 * @description Typically, a server-side call will be made using a service
 * that is defined on the ServiceLocator.  These services will either be
 * remote calls onto Java Objects (RemoteObject), Web Service invocations
 * (WebService) or XML over HTTP/HTTPS (HTTPService) service calls.
 *
 * <p>The results from these server calls will be handled by an object that has
 * been passed to the ServiceLocator as the designated "responder" (the
 * class willing to handle the response).</p>
 *
 * <p>Typically in the Cairngorm
 * architecture, the Responder interface is implemented by a concrete
 * implementation of a Command class that will use a BusinessDelegate
 * class to handle invocation of server-side business logic.</p>
 *
 * @see org.nevis.cairngorm.commands.Command
 */

import mx.rpc.ResultEvent;
import mx.rpc.FaultEvent;

interface org.nevis.cairngorm.business.Responder
{
	/**
	 * The onResult method interface is used to mark the method on a
	 * concrete Responder that will handle the results from a successful
	 * call to a server-side service.  The actual data returned will be
	 * held in event.result
	 *
	 * @param event An object containing the data passed back from the
	 * service call, it is recommended that this be immediately narrowed
	 * within the concrete responder by using an appropriate cast.  For
	 * instance, if you invoke a Java method that returns an AccountVO
	 * value object, cast event.result to an AccountVO as follows:
	 * <p>
	 * <code> var customerAccount:AccountVO = AccountVO( event.result );</code>
	 * </p>
	 * <p>
	 * It is considered good practice when building applications with the
	 * Cairngorm framework, to indicate the return types from the server
	 * by appropriate casting.
	 * </p>
	 *
	 * <p>
	 * Java Developers should take care not to use
	 * the Java casting notation - a common mistake for RIA developers
	 * migrating from J2EE development.
	 * </p>
	 */
	public function onResult( event:Object ) : Void;

//-------------------------------------------------------------------------

	/**
	 * The onFault method interface is used to mark the method on a
	 * concrete Responder that will handle the information from a failed
	 * call to a server-side service.  The actual data returned will be
	 * held in event.fault
	 *
	 * @param event An object containing the data passed back from the
	 * service call
	 */
	public function onFault( event:Object ) : Void;
}