/*

Copyright 2004 iteration::two Ltd

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

@ignore
*/

import org.nevis.cairngorm.control.Event;

/**
 * The Command interface enforces the contract between the Front
 * Controller and concrete command classes in your application.
 *	@description
 * In a Cairngorm application, the application specific Front Controller
 * will listen for events of interest, dispatching control to appropriate
 * command classes according to the type of the event broadcast.
 *
 * <p>
 * When an event is broadcast by the Front Controller, it will
 * lookup its list of registered commands, to find the command capable
 * of carrying out the appropriate work in response to the user gesture
 * that has caused the event.
 * </p>
 *
 * <p>
 * When the event that a Command is registered against is broadcast,
 * the Front Controller class will invoke the Command by calling its
 * execute() method, which can be considered the entry point to a
 * Command.
 * </p>
 *
 * @see org.nevis.cairngorm.control.FrontController
 * @see org.nevis.cairngorm.control.Event
 * @see org.nevis.cairngorm.control.EventBroadcaster
 */
interface org.nevis.cairngorm.commands.Command
{
	/** Called by the Front Controller to execute the command
    * 
	 * @description  The single entry point into a Command, the 
    * execute() method is called by the Front Controller when a 
    * user-gesture indicates that the user wishes to perform a 
    * task for which a particularconcrete command class has been 
    * provided.
	 *
	 * @param event When the Front Controller receives notification
	 * of a user gesture, the Event that it receives contains both the
	 * type of the event (indicating which command should handle the
	 * work) but also any data associated with the event.
	 *
	 * <p>
	 * For instance, if a "login" event has been broadcast,
	 * to which the controller has registered the LoginCommand,
	 * the event may also contain some associated data, such as
	 * the number of prior attempts at login have been made
	 * already.  In this case, the event.type would be set to
	 * "login" while event.data would contain (by way of example)
	 * an attribute such as event.data.attemptedLogins.
	 * </p>
	 *
	 * <p>
	 * By careful use of event.type and event.data, the same
	 * concrete command class is capable of responding in slightly
	 * different ways to similar user gesture requests.
	 * </p>
	 */
	function execute( event:Event ) : Void;
}