/*

Copyright 2004 iteration::two Ltd

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

@ignore
*/

/**
 * The Event class is used within Cairngorm to differentiate application
 * level events from events raised by the underlying Flex framework (or
 * similar)
 *	@description
 * <p>
 * Events are typically broadcast as the result of a user gesture occuring
 * in the application, such as a button click, a menu selection, a double
 * click, a drag and drop operation, etc.  These events are broadcast using
 * the singleton EventBroadcaster class, also available as part of the
 * Cairngorm framework.
 * </p>
 *
 * @see org.nevis.cairngorm.control.FrontController
 * @see org.nevis.cairngorm.control.Event
 * @see org.nevis.cairngorm.control.EventBroadcaster
 */
class org.nevis.cairngorm.control.Event
{


//------------------------------------------------------------------------------

	/**
	 * No-args constructor
	 */
	public function Event()
	{
	}

//------------------------------------------------------------------------------

	/**
	 * A name to distinguish the event that has occured.  This name will be
	 * registered with the Front Controller, against a Command class capable
	 * of doing the work necessary to respond to the event
	 */
	public var type:String;

	/**
	 * Any data stuffed into the data object on an Event, will be passed
	 * to the Command class that handles the event.  The developer is free
	 * to use this to their own advantage - a simple view helper strategy
	 * for instance, may require that an event of type "login" also has
	 * event.data.login and event.data.password broadcast, to alleviate
	 * the LoginCommand from having to interrogate the user interface.
	 */
	public var data:Object;
	
	public var view:Object;
	public var resultFunction:Object;
}